@@ -16,6 +16,8 @@ function register_user($adding_service="no"){
 
 	global $secpayconf_currency_letters;
 
+	global $pro_mysql_custom_heb_types_table;
+
 	global $gettext_lang;
 
 	get_secpay_conf();
@@ -45,10 +47,10 @@ function register_user($adding_service="no"){
 
 	if(!isRandomNum($esc_product_id)){
 		$ret["err"] = 2;
-		$ret["mesg"] = _("Product ID not valid!");
+		$ret["mesg"] = _("Product ID not valid.");
 		return $ret;
 	}
-	$q = "SELECT * FROM $pro_mysql_product_table WHERE id='$esc_product_id';";
+	$q = "SELECT $pro_mysql_product_table.*, $pro_mysql_custom_heb_types_table.reqdomain FROM $pro_mysql_product_table LEFT JOIN $pro_mysql_custom_heb_types_table ON $pro_mysql_product_table.custom_heb_type = $pro_mysql_custom_heb_types_table.id WHERE $pro_mysql_product_table.id='$esc_product_id';";
 	$r = mysql_query($q)or die("Cannot querry $q line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
 	$n = mysql_num_rows($r);
 	if($n != 1){
@@ -61,22 +63,22 @@ function register_user($adding_service="no"){
 	// Do field format checking and escaping for all fields
 	if( !preg_match("/^([a-zA-Z0-9]+)([._a-zA-Z0-9-]+)\$/",$_REQUEST["reqadm_login"]) ){
 		$ret["err"] = 2;
-		$ret["mesg"] = _("User login format incorrect. Please use letters and numbers only and from 4 to 16 chars.") ;
+		$ret["mesg"] = _("User login format incorrect. Username must contain only letters and numbers and contain 4 to 16 characters.") ;
 		return $ret;
 	}
 	if($_REQUEST["reqadm_login"] == "root" || $_REQUEST["reqadm_login"] == "debian-sys-maint"){
 		$ret["err"] = 2;
-		$ret["mesg"] = _("Username invalid: please choose something else other than root or debian-sys-maint") ;
+		$ret["mesg"] = _("Username invalid: please choose a name other than root or debian-sys-maint") ;
 		return $ret;
 	}
 	if(!isDTCPassword($_REQUEST["reqadm_pass"])){
 		$ret["err"] = 2;
-		$ret["mesg"] = _("Password format incorrect. Please use letters and numbers only and from 4 to 16 chars.") ;
+		$ret["mesg"] = _("Password format incorrect. Password must contain only letters and numbers and contain 4 to 16 characters.") ;
 		return $ret;
 	}
 	if($_REQUEST["reqadm_pass"] != $_REQUEST["reqadm_pass2"]){
 		$ret["err"] = 2;
-		$ret["mesg"] = _("Passwords 1 and 2 do not match!") ;
+		$ret["mesg"] = _("Passwords do not match.") ;
 		return $ret;
 	}
 
@@ -86,14 +88,14 @@ function register_user($adding_service="no"){
 		$domain_tld = $_REQUEST["domain_tld"];
 	}
 
-	// If shared or ssl hosting, we MUST do type checkings
-	if($db_product["heb_type"] == "shared" || $db_product["heb_type"] == "ssl" || $db_product["heb_type"] == "dedicated"){
+	// If shared or ssl hosting or custom with domain, we MUST do type checkings
+	if($db_product["heb_type"] == "shared" || $db_product["heb_type"] == "ssl" || $db_product["heb_type"] == "dedicated" || ($db_product["heb_type"] == "custom" && $db_product["reqdomain"] == "yes")){
 		if(!isHostnameOrIP($_REQUEST["domain_name"].$_REQUEST["domain_tld"])){
 			$ret["err"] = 2;
 			$ret["mesg"] = _("Domain name seems to be incorrect.") ;
 			return $ret;
 		}
-	// If not a shared, a dedicated or ssl account, it's a VPS:
+	// If not a shared, a dedicated or ssl account, it's a VPS or custom without domain:
 	// we don't care if it's umpty, but we take care of mysql insertion anyway
 	// so if there is a domain name, then we check it's consistency, but we don't
 	// do much more if there's nothing...
@@ -107,7 +109,7 @@ function register_user($adding_service="no"){
 	if($db_product["heb_type"] == "vps"){
 		if($_REQUEST["vps_server_hostname"] == "-1"){
 			$ret["err"] = 2;
-			$ret["mesg"] = _("VPS location not selected!") ;
+			$ret["mesg"] = _("VPS location not selected.") ;
 			return $ret;
 		}
 		$q = "SELECT * FROM $pro_mysql_vps_server_table WHERE hostname='".mysql_real_escape_string($_REQUEST["vps_server_hostname"])."';";
@@ -127,7 +129,7 @@ function register_user($adding_service="no"){
 
 	if(!isset($_REQUEST["familyname"]) || $_REQUEST["familyname"]==""){
 		$ret["err"] = 2;
-		$ret["mesg"] = _("Required field family name missing.") ;
+		$ret["mesg"] = _("Required field last name missing.") ;
 		return $ret;
 	}else{
 		if (!get_magic_quotes_gpc()){
@@ -245,19 +247,25 @@ function register_user($adding_service="no"){
 		return $ret;
 	}
 
-	if($_REQUEST["iscomp"] == "yes"){
-		$esc_comp = "yes";
-	}else if($_REQUEST["iscomp"] == "no"){
-		$esc_comp = "no";
+	if (isset($_REQUEST["iscomp"])){
+		if($_REQUEST["iscomp"] == "yes"){
+			$esc_comp = "yes";
+		}else if($_REQUEST["iscomp"] == "no"){
+			$esc_comp = "no";
+		}else{
+			$ret["err"] = 2;
+			$ret["mesg"] = _("Company option wrong.") ;
+			return $ret;
+		}
 	}else{
 		$ret["err"] = 2;
-		$ret["mesg"] = _("Is company radio button is wrong!") ;
+		$ret["mesg"] = _("Company option wrong.") ;
 		return $ret;
 	}
 
 	if($conf_selling_conditions_url != "none" && (!isset($_REQUEST["condition"]) || $_REQUEST["condition"] != "yes")){
 		$ret["err"] = 2;
-		$ret["mesg"] = _("Selling conditions not accepted!") ;
+		$ret["mesg"] = _("Terms and Conditions not accepted.") ;
 		return $ret;
 	}
 
@@ -266,7 +274,7 @@ function register_user($adding_service="no"){
 	$n = mysql_num_rows($r);
 	if($n > 0){
 		$ret["err"] = 3;
-		$ret["mesg"] = _("Username already taken! Try again.") ;
+		$ret["mesg"] = _("Username already taken. Try again.") ;
 		return $ret;
 	}
 	$q = "SELECT reqadm_login FROM $pro_mysql_new_admin_table WHERE reqadm_login='".$_REQUEST["reqadm_login"]."';";
@@ -274,7 +282,7 @@ function register_user($adding_service="no"){
 	$n = mysql_num_rows($r);
 	if($n > 0){
 		$ret["err"] = 3;
-		$ret["mesg"] = _("Username already taken! Try again.") ;
+		$ret["mesg"] = _("Username already taken. Try again.") ;
 		return $ret;
 	}
 	$vps_add1 = "";
@@ -417,7 +425,7 @@ VALUES('".$_REQUEST["reqadm_login"]."',
 	$r = mysql_query($q)or die("Cannot querry $q line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
 	$n = mysql_num_rows($r);
 	if($n != 1){
-		echo "<font color=\"red\">". _("Cannot find product id!") ."</font>";
+		echo "<font color=\"red\">". _("Cannot find product ID.") ."</font>";
 		$the_prod = $esc_product_id." (0 $secpayconf_currency_letters)";
 	}else{
 		$a = mysql_fetch_array($r);
@@ -431,7 +439,7 @@ VALUES('".$_REQUEST["reqadm_login"]."',
 	}
 
 	$mail_content = "
-Somebody tried to register an account. Here is the details of the new user:
+New account registered. Here are the details of the new user:
 
 login: ".$_REQUEST["reqadm_login"]."
 pass: ".$pass_for_email."
@@ -473,6 +481,8 @@ function registration_form(){
 	global $pro_mysql_vps_server_table;
 	global $pro_mysql_custom_fld_table;
 
+	global $pro_mysql_custom_heb_types_table;
+
 	global $conf_selling_conditions_url;
 	global $secpayconf_currency_symbol;
 
@@ -493,10 +503,15 @@ function registration_form(){
 		$heb_type = $a["heb_type"];
 	}else{
 		$heb_types = array('shared', 'ssl', 'vps', 'server');
-		if(isset($_REQUEST["heb_type"]) && preg_match("/[a-zA-Z0-9]/", $_REQUEST["heb_type"])){
-		    if(in_array(strtolower($_REQUEST["heb_type"]),$heb_types)){
-			$heb_type_condition = " heb_type='".strtolower($_REQUEST["heb_type"])."' ";
-			$heb_type = strtolower($_REQUEST["heb_type"]);
+		if(isset($_REQUEST["heb_type"]) && preg_match("/[a-zA-Z0-9\_]/", $_REQUEST["heb_type"])){
+		    if(in_array(strtolower($_REQUEST["heb_type"]),$heb_types) or preg_match("/custom_[0-9]{1,11}/", $_REQUEST["heb_type"])){
+				if (in_array(strtolower($_REQUEST["heb_type"]),$heb_types)){
+					$heb_type_condition = " heb_type='".strtolower($_REQUEST["heb_type"])."' ";
+					$heb_type = strtolower($_REQUEST["heb_type"]);
+				}else{
+					$heb_type_condition = " heb_type='".str_replace('custom_', '', $_REQUEST["heb_type"])."' ";
+				$heb_type = str_replace('custom_', '', $_REQUEST["heb_type"])."' ";
+				}
 		    }else{
 				$heb_type_condition = " 1 ";
 				$heb_type = "all";
@@ -509,13 +524,21 @@ function registration_form(){
 
 	$prod_popup = "";
 	$p_jscript = " prod_popup_htype = new Array();";
-	$q = "SELECT * FROM $pro_mysql_product_table WHERE $heb_type_condition AND renew_prod_id='0' AND private='no' ORDER BY id";
+	$q = "SELECT $pro_mysql_product_table.*, $pro_mysql_custom_heb_types_table.reqdomain FROM $pro_mysql_product_table LEFT JOIN $pro_mysql_custom_heb_types_table ON $pro_mysql_product_table.custom_heb_type = $pro_mysql_custom_heb_types_table.id WHERE $heb_type_condition AND renew_prod_id='0' AND private='no' ORDER BY id";
 	$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
 	$n = mysql_num_rows($r);
-	$prod_popup .= "<option value=\"-1\">"._("Please select!")."</optioon>";
+	$prod_popup .= "<option value=\"-1\">"._("Please select.")."</optioon>";
 	for($i=0;$i<$n;$i++){
 		$a = mysql_fetch_array($r);
-		$p_jscript .= " prod_popup_htype[".$a["id"]."] = '".$a["heb_type"]."';\n";
+				if ($a["heb_type"] == "custom"){
+			if($a["reqdomain"] == "yes"){
+				$p_jscript .= " prod_popup_htype[".$a["id"]."] = 'custom_domain';\n";
+			}else{
+				$p_jscript .= " prod_popup_htype[".$a["id"]."] = 'custom_nodomain';\n";
+			}
+		}else{
+			$p_jscript .= " prod_popup_htype[".$a["id"]."] = '".$a["heb_type"]."';\n";
+		}
 		if(isset($_REQUEST["product_id"]) && $a["id"] == $_REQUEST["product_id"]){
 			$prod_popup .= "<option value=\"".$a["id"]."\" selected>".$a["name"]." / ".$a["price_dollar"]."$secpayconf_currency_symbol</option>\n";
 		}else{
@@ -668,17 +691,17 @@ function registration_form(){
 	}
 	$client_info = "<table>
 <tr>
-	<td style=\"white-space: nowrap;text-align: right;\">". _("Familly name: ") . $rek ."</td>
+	<td style=\"white-space: nowrap;text-align: right;\">". _("Last Name: ") . $rek ."</td>
 	<td><input type=\"text\" name=\"familyname\" value=\"$frm_family_name\"></td>
 </tr><tr>
-	<td style=\"white-space: nowrap;text-align: right;\">". _("First name: ") . $rek ."</td>
+	<td style=\"white-space: nowrap;text-align: right;\">". _("First Name: ") . $rek ."</td>
 	<td><input type=\"text\" name=\"firstname\" value=\"$frm_firstname\"></td>
 </tr><tr>
-	<td style=\"white-space: nowrap;text-align: right;\">". _("Is it a company: ") . $rek ."</td>
+	<td style=\"white-space: nowrap;text-align: right;\">". _("Company Account: ") . $rek ."</td>
 	<td><input type=\"radio\" name=\"iscomp\" value=\"yes\"$compyes>"._("Yes")."
 <input type=\"radio\" name=\"iscomp\" value=\"no\"$compno>"._("No")."</td>
 </tr><tr>
-	<td style=\"white-space: nowrap;text-align: right;\">". _("Company name: ") ."</td>
+	<td style=\"white-space: nowrap;text-align: right;\">". _("Company Name: ") ."</td>
 	<td><input type=\"text\" name=\"compname\" value=\"$frm_compname\"></td>
 </tr><tr>
 	<td style=\"white-space: nowrap;text-align: right;\">". _("VAT/GST Number: ") ."</td>
@@ -687,7 +710,7 @@ function registration_form(){
 	<td style=\"white-space: nowrap;text-align: right;\">". _("Email: ") . $rek ."</td>
 	<td><input type=\"text\" name=\"email\" value=\"$frm_email\"></td>
 </tr><tr>
-	<td style=\"white-space: nowrap;text-align: right;\">". _("Phone number: ") . $rek ."</td>
+	<td style=\"white-space: nowrap;text-align: right;\">". _("Phone Number: ") . $rek ."</td>
 	<td><input type=\"text\" name=\"phone\" value=\"$frm_phone\"></td>
 </tr><tr>
 	<td style=\"white-space: nowrap;text-align: right;\">". _("Fax: ") ."</td>
@@ -727,7 +750,7 @@ function registration_form(){
 	$addr_skined = $client_addr;
 
 	if($conf_selling_conditions_url != "none"){
-		$conditions = "<input type=\"checkbox\" name=\"condition\" value=\"yes\"> " . $rek  . _("I agree to the") ." <a href=\"$conf_selling_conditions_url\">". _("selling conditions") ."</a>";
+		$conditions = "<input type=\"checkbox\" name=\"condition\" value=\"yes\"> " . $rek  . _("I agree to the") ." <a href=\"$conf_selling_conditions_url\">". _("Terms and Conditions") ."</a>";
 	}else{
 		$conditions = "";
 	}
@@ -782,7 +805,7 @@ function registration_form(){
 				}else{
 					$val = "";
 				}
-				$cust_out .= "<textarea name=\"".$a["varname"]."\">".$val."</textarea>";
+				$cust_out .= "<textarea cols=\"60\" rows=\"7\" name=\"".$a["varname"]."\">".$val."</textarea>";
 				break;
 			case "text":
 			default:
@@ -791,7 +814,7 @@ function registration_form(){
 				}else{
 					$val = "";
 				}
-				$cust_out .= "<input type=\"text\" name=\"".$a["varname"]."\" value=\"$val\">";
+				$cust_out .= "<input size=\"60\" type=\"text\" name=\"".$a["varname"]."\" value=\"$val\">";
 				break;
 			}
 			$cust_out .= "</td></tr>";
@@ -844,6 +867,20 @@ function hostingProductChanged(){
 		e.style.display = 'block';
 		f.style.visibility = 'visible';
 		f.style.display = 'block';
+		}else if(hosting_type == 'custom_nodomain'){
+		a.style.visibility = 'hidden';
+		a.style.display = 'none';
+		b.style.visibility = 'hidden';
+		b.style.display = 'none';
+
+		c.style.visibility = 'hidden';
+		c.style.display = 'none';
+		d.style.visibility = 'hidden';
+		d.style.display = 'none';
+		e.style.visibility = 'hidden';
+		e.style.display = 'none';
+		f.style.visibility = 'hidden';
+		f.style.display = 'none';
 	}else{
 		a.style.visibility = 'visible';
 		a.style.display = 'block';
@@ -863,7 +900,7 @@ function hostingProductChanged(){
 
 </script><br>
 <br>
-<i>" . _("Feilds with a <font color=\"red\">*</font> are mandatory.") . "</i><br>
+<i>" . _("Fields with a <font color=\"red\">*</font> are mandatory.") . "</i><br>
 <form name=\"newuser_form\" action=\"?\" methode=\"post\">
 <input type=\"hidden\" name=\"action\" value=\"new_user_request\">
 <table>
