@@ -15,6 +15,7 @@ if($panel_type !="email"){
 	require("$dtcshared_path/inc/forms/domain_stats.php");
 	require("$dtcshared_path/inc/forms/dns.php");
 	require("$dtcshared_path/inc/forms/subdomain.php");
+	require("$dtcshared_path/inc/forms/user_cronjobs.php");
 	require("$dtcshared_path/inc/forms/lists.php");
 	require("$dtcshared_path/inc/forms/ticket.php");
 	//udns.us add
@@ -27,6 +28,7 @@ if($panel_type !="email"){
 	require("$dtcshared_path/inc/forms/vps_dom0graphs.php");
 	require("$dtcshared_path/inc/forms/vps_installation.php");
 	require("$dtcshared_path/inc/forms/dedicated.php");
+	require("$dtcshared_path/inc/forms/multiple_renew.php");
 }
 require("$dtcshared_path/inc/forms/email.php");
 require("$dtcshared_path/inc/forms/aliases.php");
@@ -46,23 +48,29 @@ function drawPasswordChange(){
 	global $adm_pass;
 	global $addrlink;
 	global $pro_mysql_admin_table;
+	global $conf_enforce_adm_encryption;
 
 	$pass_submit_err = "";
 
 	if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "change_adm_pass"){
 	        $commit_flag = "yes"; //Init the commit_flag
 		if(!isDTCPassword($_REQUEST["new_pass1"]) || !isDTCPassword($_REQUEST["new_pass2"])){
-			$pass_submit_err .= _("This is not a valid password!")."<br>\n";
+			$pass_submit_err .= _("This is not a valid password.")."<br>\n";
 			$commit_flag = "no";
 		}
 		if($_REQUEST["new_pass1"] != $_REQUEST["new_pass2"]){
-			$pass_submit_err .= _("Password 1 does not match password 2!")."<br>\n";
+			$pass_submit_err .= _("Passwords do not match.")."<br>\n";
 			$commit_flag = "no";
 		}
 		if($commit_flag == "yes"){
-			$q = "UPDATE $pro_mysql_admin_table SET adm_pass='".$_REQUEST["new_pass1"]."' WHERE adm_login='$adm_login';";
+			if($conf_enforce_adm_encryption == "yes"){
+				$new_password_encrypted = "SHA1('".$_REQUEST["new_pass1"]."')";
+			}else{
+				$new_password_encrypted = "'".$_REQUEST["new_pass1"]."'";
+			}
+			$q = "UPDATE $pro_mysql_admin_table SET adm_pass=$new_password_encrypted WHERE adm_login='$adm_login';";
 			$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
-			$pass_submit_err .= _("Your administrator password has been changed!")."<br>\n";
+			$pass_submit_err .= _("Your administrator password has been changed.")."<br>\n";
 		}
 	}
 
@@ -139,6 +147,7 @@ function drawAdminTools($admin){
 	$allow_dns_and_mx_change = $admin_info["allow_dns_and_mx_change"];
 	$allow_mailing_list_edit = $admin_info["allow_mailing_list_edit"];
 	$allow_subdomain_edit = $admin_info["allow_subdomain_edit"];
+	$allow_cronjob_edit = $admin_info["allow_cronjob_edit"];
 
 	unset($user_ZEmenu);
 	if($nbr_domain > 0){
@@ -158,9 +167,14 @@ function drawAdminTools($admin){
 		"icon" => "box_wnb_nb_picto-addadomainname.gif",
 		"type" => "link",
 		"link" => "adddomain");
+	$user_ZEmenu[] = array(
+		"text" => _("Multiple renew") ,
+		"icon" => "box_wnb_nb_picto-addadomainname.gif",
+		"type" => "link",
+		"link" => "multiple-renew");
 	if($conf_use_registrar_api == "yes" && $nbr_domain > 0){
 		$user_ZEmenu[] = array(
-			"text" => _("DNS Nick handles") ,
+			"text" => _("DNS NIC handles") ,
 			"icon" => "box_wnb_nb_picto-nickhandles.gif",
 			"type" => "link",
 			"link" => "nickhandles");
@@ -263,6 +277,13 @@ function drawAdminTools($admin){
 					"type" => "link",
 					"link" => "subdomains");
 			}
+			if($allow_cronjob_edit == "yes"){
+				$domain_conf_submenu[] = array(
+					"text" => _("Cron jobs"),
+					"icon" => "box_wnb_nb_picto-subdomains.gif",
+					"type" => "link",
+					"link" => "cronjobs");
+			}
                         if($ftp_login_flag == "yes"){
 				$domain_conf_submenu[] = array(
 					"text" => _("FTP accounts") ,
@@ -477,6 +498,10 @@ function drawAdminTools($admin){
                         $web_editor .= "<img src=\"gfx/toolstitles/subdomains.png\" align=\"left\"><font size=\"+2\"><b><u>". _("Subdomains:") ."</u></b><br></font>";
 			$web_editor .= drawAdminTools_Subdomain($admin,$eddomain);
 			$title = _("Subdomains of ") .$edit_domain;
+		}else if(@$add_array[1] == "cronjobs"){
+			$web_editor .= "<img src=\"gfx/toolstitles/subdomains.png\" align=\"left\"><font size=\"+2\"><b><u>". _("Cron jobs:") ."</u></b><br></font>";
+			$web_editor .= drawAdminTools_User_CronJob($admin,$eddomain);
+			$title = _("Cron jobs of ") .$edit_domain;
 		}else if(@$add_array[1] == "ftp-accounts"){
                         $web_editor .= "<img src=\"gfx/toolstitles/ftp-accounts.png\" align=\"left\"><font size=\"+2\"><b><u>". _("FTP accounts") ."</u></b><br></font>";
 			$web_editor .= drawAdminTools_Ftp($eddomain,$adm_path);
@@ -490,13 +515,17 @@ function drawAdminTools($admin){
 			$web_editor .= drawAdminTools_PackageInstaller($eddomain,$adm_path);			
 			$title = _("Package") .": ".$edit_domain;
 		}else if(@$add_array[1] == "nickhandles"){
-                        $web_editor .= "<img src=\"gfx/toolstitles/nickhandles.png\" align=\"left\"><font size=\"+2\"><b><u>". _("DNS Nick handles") ."</u></b><br></font>";
+                        $web_editor .= "<img src=\"gfx/toolstitles/nickhandles.png\" align=\"left\"><font size=\"+2\"><b><u>". _("DNS NIC handles") ."</u></b><br></font>";
 			$web_editor .= drawAdminTools_NickHandles($admin);
-			$title = _("Internet Whois Nick Handles management:") ;
+			$title = _("Internet Whois NIC Handle management:") ;
 		}else if(@$add_array[1] == "adddomain"){
                         $web_editor .= "<img src=\"gfx/toolstitles/adddomain.png\" align=\"left\"><font size=\"+2\"><b><u>". _("Add a domain or service:") ."</u></b><br></font>";
 			$web_editor .= drawAdminTools_AddDomain($admin);
 			$title = _("Add a domain name to my account") ;
+		}else if(@$add_array[1] == "multiple-renew"){
+                        $web_editor .= "<img src=\"gfx/toolstitles/adddomain.png\" align=\"left\"><font size=\"+2\"><b><u>". _("Renewals:") ."</u></b><br></font>";
+			$web_editor .= drawAdminTools_MultipleRenew($admin);
+			$title = _("Renew multiple services at once") ;
 		}else if(@$add_array[1] == "nameservers"){
                         $web_editor .= "<img src=\"gfx/toolstitles/nameservers.png\" align=\"left\"><font size=\"+2\"><b><u>". _("Name servers:") ."</u></b><br></font>";
 			$web_editor .= drawAdminTools_NameServers($admin);
@@ -519,7 +548,7 @@ function drawAdminTools($admin){
 		}else if($add_array[0] == "reseller"){
                         $web_editor .= "<img src=\"gfx/toolstitles/reseller.png\" align=\"left\"><font size=\"+2\"><b><u>"._("Sub-accounts (reseller):") ."</u></b><br></font>";
 			$web_editor .= drawReseller($admin);	
-			$title = _("Resseller child accounts");
+			$title = _("Reseller child accounts");
 		}else if($add_array[0] == "password"){
                         $web_editor .= "<img src=\"gfx/toolstitles/password.png\" align=\"left\"><font size=\"+2\"><b><u>". _("Password:") ."</u></b><br></font>";
 			$web_editor .= drawPasswordChange();
@@ -535,7 +564,7 @@ function drawAdminTools($admin){
 <div align=\"justify\">
 <font size=\"+1\"><u>1. What is DTC</u></font><br><br>
 DTC is a tool we made especialy for you. With it, you can take the control of your domain administration : you can manage all your
-subdomains, emails, ftp or ssh accounts, and manage your VPS. DTC does also billing and invoices, plus many other things.<br><br>
+subdomains, email boxes, ftp or ssh accounts, and manage your VPS. DTC also does billing and invoices, plus many other things.<br><br>
 
 All this tool and all the software it uses and configure have been release under the <a href=\"http://www.gnu.org/\">GPL</a>
 (GNU Public Licence), which means that you can have a copy of this interface source code, modify it and use it as you wish, as long as
@@ -638,7 +667,7 @@ effect in realtime.<br><br>
 		}else{
                         $web_editor .= "<img src=\"gfx/toolstitles/domains.png\" align=\"left\"><font size=\"+2\"><b><u>$addrlink:</u></b><br></font>";
 			$web_editor .= drawAdminTools_DomainInfo($admin,$eddomain);
-			$title = _("General information of ") .$edit_domain;
+			$title = _("General Information ") .$edit_domain;
 		}
 		$edition = skin($conf_skin,$web_editor,$title);
 	}else{
