@@ -26,6 +26,13 @@ function drawTickets($admin){
 				$popup_hostname .= "<option value=\"$vps_name\">$vps_name</option>";
 			}
 		}
+		if(isset($admin["dedicated"])){
+			$nbr_dedicated = sizeof($admin["dedicated"]);
+			for($i=0;$i<$nbr_dedicated;$i++){
+				$dedi_name = $admin["dedicated"][$i]["server_hostname"];
+				$popup_hostname .= "<option value=\"$dedi_name\">$dedi_name</option>";
+			}
+		}
 
 		$q = "SELECT * FROM $pro_mysql_tik_cats_table WHERE 1 ORDER BY id";
 		$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
@@ -72,16 +79,16 @@ $popup_cats
 		$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 		$n = mysql_num_rows($r);
 		if($n != 1){
-			$out .= _("Ticket not found!") ;
+			$out .= _("Ticket not found.") ;
 		}else{
 			$a_t = mysql_fetch_array($r);
-			$out .= _("Subject:") ." ".stripslashes($a_t["subject"])."<br>";
+			$out .= _("Subject:") ." ".htmlspecialchars(stripslashes($a_t["subject"]))."<br>";
 
 			$q2 = "SELECT * FROM $pro_mysql_tik_cats_table WHERE id='".$a_t["cat_id"]."';";
 			$r2 = mysql_query($q2)or die("Cannot query $q2 line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 			$n2 = mysql_num_rows($r2);
 			if($n2 != 1){
-				$out .= _("Type: type not found!") ;
+				$out .= _("Type: type not found.") ;
 			}else{
 				$a2 = mysql_fetch_array($r2);
 				$out .= _("Type of problem:") ." ".$a2["catdescript"]."<br>";
@@ -100,7 +107,7 @@ $popup_cats
 				$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 				$n = mysql_num_rows($r);
 				if($n != 1){
-					$out .= _("Ticket not found!") ;
+					$out .= _("Ticket not found.") ;
 					break;
 				}
 				$a = mysql_fetch_array($r);
@@ -121,11 +128,11 @@ $popup_cats
 					}else{
 						$realname = _("Not found!");
 					}
-					$replied_by = "<br>"._("Replied by:")." ".$realname;
+					$replied_by = "<br>"._("Replied to By:")." ".$realname;
 				}else{
 					$replied_by = "";
 				}
-				$out .= "<tr><td$bg valign=\"top\"><i>".$a["date"]." ".$a["time"]."</i>".$replied_by."</td><td$bg>".nl2br(stripslashes($a["text"]))."</td></tr>";
+				$out .= "<tr><td$bg valign=\"top\"><i>".$a["date"]." ".$a["time"]."</i>".$replied_by."</td><td$bg>".nl2br(htmlspecialchars(stripslashes($a["text"])))."</td></tr>";
 			}
 			$out .= "</table>";
 			$out .= "<form action=\"?\" method=\"post\">
