@@ -149,8 +149,10 @@ function drawAdminTools_VPSInstallation($admin,$vps){
 	for($i=0;$i<$n;$i++){
 		if($i % 2){
 			$alt_color = 0;
+			$class_type = "";
 		}else{
 			$alt_color = 1;
+			$class_type = "class=\"alternatecolorline\"";
 		}
 		$q = "SELECT * FROM $pro_mysql_vps_ip_table WHERE ip_addr='".$vps_ips[$i]."';";
 		$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
@@ -164,10 +166,10 @@ function drawAdminTools_VPSInstallation($admin,$vps){
 			$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 			$ip_pool_row = mysql_fetch_array($r);
 
-			$out .= dtcFormLineDraw($vps_ips[$i] . '</th><th class="alternatecolorline">' . $ip_pool_row['netmask'] . '</th><th class="alternatecolorline">' . $ip_pool_row['gateway'] . '</th><th class="alternatecolorline">' . $ip_pool_row['dns'],
+			$out .= dtcFormLineDraw($vps_ips[$i] . "</th><td $class_type>" . $ip_pool_row['netmask'] . "</td><td $class_type>" . $ip_pool_row['gateway'] . "</td><td $class_type>" . $ip_pool_row['dns'],
 	"$frm_start<input type=\"hidden\" name=\"action\" value=\"set_ip_reverse_dns\">
 	<input type=\"hidden\" name=\"ip_addr\" value=\"".$vps_ips[$i]."\">
-	<input type=\"text\" name=\"rdns\" value=\"".$a["rdns_addr"]."\">
+	<input size=\"40\" type=\"text\" name=\"rdns\" value=\"".$a["rdns_addr"]."\">
 </td><td><div class=\"input_btn_container\" onMouseOver=\"this.className='input_btn_container-hover';\"
 onMouseOut=\"this.className='input_btn_container';\">
  <div class=\"input_btn_left\"></div>
