@@ -59,4 +59,7 @@ $pro_mysql_radreply_table = "radreply";
 $pro_mysql_radcheck_table = "radcheck";
 $pro_mysql_custom_fld_table = "custom_fld";
 $pro_mysql_user_cron_table = "user_cron";
+$pro_mysql_custom_heb_types_table = "custom_heb_types";
+$pro_mysql_custom_heb_types_fld_table = "custom_heb_types_fld";
+$pro_mysql_custom_product_table = "custom_product";
 ?>
